@@ -5,6 +5,7 @@ import threading
 import os
 import sys
 
+from core import constants
 from core.backports.six import b
 from core.backports import six
 
@@ -231,4 +232,28 @@ def bytes2PrettyUnitString(bytes):
         size = '%.2fKB' % kilobytes
     else:
         size = '%.2fb' % bytes
-    return size
\ No newline at end of file
+    return size
+
+def freeSpaceInPath(path):
+    """Return free space in the given path in bytes
+
+    :param string path: path to check
+    :returns: free space in path in bytes
+    :rtype: int
+    """
+    f = os.statvfs(path)
+    return f.f_bsize * f.f_bavail
+
+def createConnectionPool(url, maxThreads=1):
+    """Create the connection pool -> to facilitate socket reuse
+
+    :param string url: root URL for the threadpool
+    :param int maxThreads: pool capacity
+    """
+    # only import urllib3 once needed
+    if sys.version_info[:2] <= (2, 5):
+        from core.backports import urllib3_python25 as urllib3
+    else:
+        from core.bundle import urllib3
+    return urllib3.connection_from_url(url, timeout=constants.INTERNET_CONNECTIVITY_TIMEOUT,
+                                       maxsize=maxThreads, block=False)
\ No newline at end of file
